@@ -5,9 +5,9 @@ use strict;
 use Regexp::Pattern::Float;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-09-23'; # DATE
+our $DATE = '2023-09-03'; # DATE
 our $DIST = 'Sah-Schemas-Str'; # DIST
-our $VERSION = '0.013'; # VERSION
+our $VERSION = '0.014'; # VERSION
 
 our $schema = [str => {
     summary => 'A number in percent form, e.g. "10.5%"',
@@ -46,7 +46,7 @@ Sah::Schema::percent_str - A number in percent form, e.g. "10.5%"
 
 =head1 VERSION
 
-This document describes version 0.013 of Sah::Schema::percent_str (from Perl distribution Sah-Schemas-Str), released on 2022-09-23.
+This document describes version 0.014 of Sah::Schema::percent_str (from Perl distribution Sah-Schemas-Str), released on 2023-09-03.
 
 =head1 SYNOPSIS
 
@@ -72,7 +72,7 @@ To check data against this schema (requires L<Data::Sah>):
  my $validator = gen_validator("percent_str*");
  say $validator->($data) ? "valid" : "INVALID!";
 
-The above schema returns a boolean result (true if data is valid, false if
+The above validator returns a boolean result (true if data is valid, false if
 otherwise). To return an error message string instead (empty string if data is
 valid, a non-empty error message otherwise):
 
@@ -84,12 +84,12 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
- $data = "1 %";
+ $data = "";
  my $errmsg = $validator->($data); # => "Must match regex pattern qr(\\A(?^:[+-]?(?:[0-9]+(?:\\.[0-9]*)?|[0-9]*\\.[0-9]+))%\\z)"
 
-Often a schema has coercion rule or default value, so after validation the
-validated value is different. To return the validated (set-as-default, coerced,
-prefiltered) value:
+Often a schema has coercion rule or default value rules, so after validation the
+validated value will be different from the original. To return the validated
+(set-as-default, coerced, prefiltered) value:
 
  my $validator = gen_validator("percent_str", {return_type=>'str_errmsg+val'});
  my $res = $validator->($data); # [$errmsg, $validated_val]
@@ -99,8 +99,8 @@ prefiltered) value:
  my $res = $validator->($data); # => ["","-1.23%"]
  
  # a sample invalid data
- $data = "1 %";
- my $res = $validator->($data); # => ["Must match regex pattern qr(\\A(?^:[+-]?(?:[0-9]+(?:\\.[0-9]*)?|[0-9]*\\.[0-9]+))%\\z)","1 %"]
+ $data = "";
+ my $res = $validator->($data); # => ["Must match regex pattern qr(\\A(?^:[+-]?(?:[0-9]+(?:\\.[0-9]*)?|[0-9]*\\.[0-9]+))%\\z)",""]
 
 Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
@@ -163,6 +163,36 @@ L<Perinci::CmdLine> (L<Perinci::CmdLine::Lite>) to create a CLI:
 
  % ./myapp.pl --arg1 ...
 
+=head2 Using on the CLI with validate-with-sah
+
+To validate some data on the CLI, you can use L<validate-with-sah> utility.
+Specify the schema as the first argument (encoded in Perl syntax) and the data
+to validate as the second argument (encoded in Perl syntax):
+
+ % validate-with-sah '"percent_str*"' '"data..."'
+
+C<validate-with-sah> has several options for, e.g. validating multiple data,
+showing the generated validator code (Perl/JavaScript/etc), or loading
+schema/data from file. See its manpage for more details.
+
+
+=head2 Using with Type::Tiny
+
+To create a type constraint and type library from a schema (requires
+L<Type::Tiny> as well as L<Type::FromSah>):
+
+ package My::Types {
+     use Type::Library -base;
+     use Type::FromSah qw( sah2type );
+
+     __PACKAGE__->add_type(
+         sah2type('percent_str*', name=>'PercentStr')
+     );
+ }
+
+ use My::Types qw(PercentStr);
+ PercentStr->assert_valid($data);
+
 =head1 DESCRIPTION
 
 This schema accepts floating number followed by percent sign. Unlike the
@@ -205,7 +235,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022, 2020 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2023, 2022, 2020 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
