@@ -3,9 +3,9 @@ package Sah::Schemas::Str;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-09-23'; # DATE
+our $DATE = '2023-09-03'; # DATE
 our $DIST = 'Sah-Schemas-Str'; # DIST
-our $VERSION = '0.013'; # VERSION
+our $VERSION = '0.014'; # VERSION
 
 1;
 # ABSTRACT: Various string schemas
@@ -22,7 +22,7 @@ Sah::Schemas::Str - Various string schemas
 
 =head1 VERSION
 
-This document describes version 0.013 of Sah::Schemas::Str (from Perl distribution Sah-Schemas-Str), released on 2022-09-23.
+This document describes version 0.014 of Sah::Schemas::Str (from Perl distribution Sah-Schemas-Str), released on 2023-09-03.
 
 =head1 SAH SCHEMAS
 
@@ -128,6 +128,10 @@ L<Sah> - schema specification
 
 L<Data::Sah> - Perl implementation of Sah
 
+=head2 Related schemas from L<Sah::Schemas::Re>
+
+L<Sah::Schema::re_from_str>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
@@ -152,7 +156,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022, 2020 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2023, 2022, 2020 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
